import os
import subprocess
from pathlib import Path

from GeneralAgent import Agent

from aicli.conf import settings
from aicli.role import SYSTEM_PROMPT


def run_command(command: str):
    """
    Execute the given command line instruction.

    Args:
        command (str): The command line instruction to be executed.

    Returns:
        str: The standard output result of the command execution.
    """
    result = subprocess.run(command, shell=True, capture_output=True, text=True)
    return result.stdout


agent = Agent(
    role=SYSTEM_PROMPT,
    workspace=Path(os.getcwd()) / ".workspace",
    functions=[run_command],
    api_key=settings.api_key,
    base_url=settings.base_url,
    model=settings.model,
)

if __name__ == "__main__":
    ret = agent.user_input("use du tell me the size of pwd")
    print(ret)



import os

from pydantic_settings import BaseSettings


class Config(BaseSettings):
    class Config:
        env_file = ".env"

    api_key: str = os.getenv("API_KEY")
    base_url: str = os.getenv("BASE_URL")
    model: str = os.getenv("MODEL")


settings = Config()



from pathlib import Path

from setuptools import find_packages, setup

# 读取 README 文件内容
this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text(encoding="utf-8")

setup(
    name="aicli-agent",
    version="0.1.2",
    packages=find_packages(),
    include_package_data=True,
    install_requires=[
        "Click",
        "pydantic-settings",
        "generalagent",
        "rich",
        # 添加其他依赖项
    ],
    entry_points={
        "console_scripts": [
            "aicli=aicli:cli",
        ],
    },
    url="https://github.com/callmexss/aicli",  # 项目主页
    project_urls={
        "PyPI": "https://pypi.org/project/aicli-agent/",  # PyPI 链接
    },
    long_description=long_description,
    long_description_content_type="text/markdown",
)



import cProfile
import io
import pstats
from functools import wraps


def profile(func):
    @wraps(func)
    def wrapper(*args, **kwargs):
        pr = cProfile.Profile()
        pr.enable()
        result = func(*args, **kwargs)
        pr.disable()
        s = io.StringIO()
        ps = pstats.Stats(pr, stream=s).sort_stats("cumulative")
        ps.print_stats()
        print("性能分析结果:")
        print(s.getvalue())
        return result

    return wrapper
